main function
void
main()
Implementation
void main() {
// Needed to not have the default path be /#/
runApp(const BirdPress());
}
void main() {
// Needed to not have the default path be /#/
runApp(const BirdPress());
}